==> qtjambi-remoteobjects-6.2.11-sources.jar: io/qt/remoteobjects/QRemoteObjectSettingsStore.java <==
package io.qt.remoteobjects;


/**
 * <p>Java wrapper for Qt class QRemoteObjectSettingsStore</p>
 */
public class QRemoteObjectSettingsStore extends io.qt.remoteobjects.QRemoteObjectAbstractPersistedStore
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectSettingsStore.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectSettingsStore(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectSettingsStore() {
        this((io.qt.core.QObject)null);
    }
    
    public QRemoteObjectSettingsStore(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRemoteObjectSettingsStore instance, io.qt.core.QObject parent);
    
    @io.qt.QtUninvokable
    public java.util.List<java.lang.Object> restoreProperties(java.lang.String repName, io.qt.core.QByteArray repSig){
        return restoreProperties_native_cref_QString_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig));
    }
    
    @io.qt.QtUninvokable
    private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
    
    @io.qt.QtUninvokable
    public void saveProperties(java.lang.String repName, io.qt.core.QByteArray repSig, java.util.Collection<? extends java.lang.Object> values){
        saveProperties_native_cref_QString_cref_QByteArray_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig), values);
    }
    
    @io.qt.QtUninvokable
    private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<? extends java.lang.Object> values);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRemoteObjectSettingsStore(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRemoteObjectSettingsStore(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRemoteObjectSettingsStore instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-remoteobjects-6.2.12-sources.jar: io/qt/remoteobjects/QRemoteObjectSettingsStore.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QRemoteObjectSettingsStore</p>
 */
public class QRemoteObjectSettingsStore extends io.qt.remoteobjects.QRemoteObjectAbstractPersistedStore
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRemoteObjectSettingsStore.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRemoteObjectSettingsStore() {
        this((io.qt.core.QObject)null);
    }
    
    public QRemoteObjectSettingsStore(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRemoteObjectSettingsStore instance, io.qt.core.QObject parent);
    
    @QtUninvokable
    public java.util.@NonNull List<java.lang.Object> restoreProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig){
        return restoreProperties_native_cref_QString_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig));
    }
    
    @QtUninvokable
    private native java.util.List<java.lang.Object> restoreProperties_native_cref_QString_cref_QByteArray(long __this__nativeId, java.lang.String repName, long repSig);
    
    @QtUninvokable
    public void saveProperties(java.lang.@NonNull String repName, io.qt.core.@NonNull QByteArray repSig, java.util.@NonNull Collection<? extends java.lang.Object> values){
        saveProperties_native_cref_QString_cref_QByteArray_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), repName, QtJambi_LibraryUtilities.internal.checkedNativeId(repSig), values);
    }
    
    @QtUninvokable
    private native void saveProperties_native_cref_QString_cref_QByteArray_cref_QList(long __this__nativeId, java.lang.String repName, long repSig, java.util.Collection<? extends java.lang.Object> values);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QRemoteObjectSettingsStore(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QRemoteObjectSettingsStore(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRemoteObjectSettingsStore instance, QDeclarativeConstructor constructor);
    
}
